# Movable Type plugin for filtering duplicate trackback ping.
#
# Release 1.02 (May 30, 2005)
#
# This software is provided as-is. You may use it for commercial or 
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2005 http://www.koikikukan.com/

package MT::Plugin::DuplicateTBPingFilter;
use strict;

# Set how to filter the title.
# 0:skip / 1:check
our $title = 1;

# Set how to filter the excerpt.
# 0:skip / 1:check
our $excerpt = 1;

# Set the checked number of track backs.
our $counter = 0;

require MT::Plugin;
my $plugin = new MT::Plugin({
    name => 'Duplicate Trackback Ping Filter Plugin 1.02',
    description => 'Filter duplicate trackback ping to the same entry.',
});
MT->add_plugin($plugin);
MT->add_callback('TBPingFilter', 11, 'duplicate trackback ping filter', \&duplicate_tbping_filter);

use MT::TBPing;
use MT::Trackback;

sub is_same_url {
   my ($new_url, $old_url) = @_;
   return ($new_url eq $old_url);
}

sub is_same_title {
    my ($new_title, $old_title) = @_;
    if (!$title) {
        return 1;
    } else {
        return ($new_title eq $old_title);
    }
}

sub is_same_excerpt {
    my ($new_excerpt, $old_excerpt) = @_;
    if (!$excerpt) {
        return 1;
    } else {
        return ($new_excerpt eq $old_excerpt);
    }
}

sub duplicate_tbping_filter {
    my ($eh, $app, $ping) = @_;
    my $ping_iter = MT::TBPing->load_iter({tb_id=>$ping->tb_id},
                                          {'sort' => 'created_on',direction => 'descend'});
    while (my $old_ping = $ping_iter->()) {
         if ($ping->id ne $old_ping->id) {
             if (&is_same_url($ping->source_url, $old_ping->source_url) &&
                 &is_same_title($ping->title, $old_ping->title) &&
                 &is_same_excerpt($ping->excerpt, $old_ping->excerpt)) {
                 $app->log("Filter duplicate trackback ping from the following URL:" . $ping->source_url);
                 return 0;
             }
         }
         if ($counter) {
             $counter--;
             if (!$counter) {
                 return 1;
             }
         }
    }
    return 1;
}

1;
